==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/aws/v1/PrivateLinkAccessBuilder.java <==
package io.fabric8.openshift.api.model.hive.aws.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PrivateLinkAccessBuilder extends PrivateLinkAccessFluentImpl<PrivateLinkAccessBuilder> implements VisitableBuilder<PrivateLinkAccess,PrivateLinkAccessBuilder>{
  public PrivateLinkAccessBuilder() {
    this(false);
  }
  public PrivateLinkAccessBuilder(Boolean validationEnabled) {
    this(new PrivateLinkAccess(), validationEnabled);
  }
  public PrivateLinkAccessBuilder(PrivateLinkAccessFluent<?> fluent) {
    this(fluent, false);
  }
  public PrivateLinkAccessBuilder(PrivateLinkAccessFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PrivateLinkAccess(), validationEnabled);
  }
  public PrivateLinkAccessBuilder(PrivateLinkAccessFluent<?> fluent,PrivateLinkAccess instance) {
    this(fluent, instance, false);
  }
  public PrivateLinkAccessBuilder(PrivateLinkAccessFluent<?> fluent,PrivateLinkAccess instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withEnabled(instance.getEnabled());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PrivateLinkAccessBuilder(PrivateLinkAccess instance) {
    this(instance,false);
  }
  public PrivateLinkAccessBuilder(PrivateLinkAccess instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withEnabled(instance.getEnabled());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PrivateLinkAccessFluent<?> fluent;
  Boolean validationEnabled;
  public PrivateLinkAccess build() {
    PrivateLinkAccess buildable = new PrivateLinkAccess(fluent.getEnabled());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/aws/v1/PrivateLinkAccessBuilder.java <==
package io.fabric8.openshift.api.model.hive.aws.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PrivateLinkAccessBuilder extends PrivateLinkAccessFluent<PrivateLinkAccessBuilder> implements VisitableBuilder<PrivateLinkAccess,PrivateLinkAccessBuilder>{
  public PrivateLinkAccessBuilder() {
    this(false);
  }
  public PrivateLinkAccessBuilder(Boolean validationEnabled) {
    this(new PrivateLinkAccess(), validationEnabled);
  }
  public PrivateLinkAccessBuilder(PrivateLinkAccessFluent<?> fluent) {
    this(fluent, false);
  }
  public PrivateLinkAccessBuilder(PrivateLinkAccessFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PrivateLinkAccess(), validationEnabled);
  }
  public PrivateLinkAccessBuilder(PrivateLinkAccessFluent<?> fluent,PrivateLinkAccess instance) {
    this(fluent, instance, false);
  }
  public PrivateLinkAccessBuilder(PrivateLinkAccessFluent<?> fluent,PrivateLinkAccess instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new PrivateLinkAccess());

    if (instance != null) {
      fluent.withEnabled(instance.getEnabled());
      fluent.withEnabled(instance.getEnabled());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PrivateLinkAccessBuilder(PrivateLinkAccess instance) {
    this(instance,false);
  }
  public PrivateLinkAccessBuilder(PrivateLinkAccess instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new PrivateLinkAccess());

    if (instance != null) {
      this.withEnabled(instance.getEnabled());
      this.withEnabled(instance.getEnabled());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PrivateLinkAccessFluent<?> fluent;
  Boolean validationEnabled;
  public PrivateLinkAccess build() {
    PrivateLinkAccess buildable = new PrivateLinkAccess(fluent.getEnabled());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
